Crate magic_dashboard

Crate magic_dashboard 

Re-exports

pub use serde_json;

Structs

DashboardRunner
A wrapper to share state safely between the main thread and the web server

Traits

DashboardState
The trait that will be implemented by the macro

Derive Macros

Dashboard