Crate magic_dashboard
magic_
dashboard
0.1.0
All Items
Crate Items
Re-exports
Structs
Traits
Derive Macros
Crate
magic_
dashboard
Re-exports

pub use
serde_json
;
Structs

Dashboard
Runner
A wrapper to share state safely between the main thread and the web server
Traits

Dashboard
State
The trait that will be implemented by the macro
Derive Macros

Dashboard